@@ -245,10 +245,8 @@ pub fn export_entry_content<D: DataProvider>(ui_components: &mut UIComponents, a
             Ok(popup) => ui_components
                 .popup_stack
                 .push(Popup::Export(Box::new(popup))),
-            Err(err) => ui_components.show_err_msg(format!(
-                "Error while creating export dialog.\n Err: {}",
-                err
-            )),
+            Err(err) => ui_components
+                .show_err_msg(format!("Error while creating export dialog.\n Err: {err}")),
         }
     }
 }
